@@ -25,3 +25,12 @@ class DatabaseAlreadyExists(Exception):
 class DatabaseDoesNotExist(Exception):
     """Raised when trying to delete the database but the db is not there"""
 
+class KeypairNotFoundException(Exception):
+    """Raised if operation cannot proceed because the keypair was not given"""
+
+class KeypairMismatchException(Exception):
+    """Raised if the private key(s) provided for signing don't match any of the curret owner(s)"""
+
+class StartupError(Exception):
+    """Raised when there is an error starting up the system"""
+
